# craft2d


## Skills
### Easy
1. Get wood: Tree 
2. Get stone: Stone
3. Get grass: Grass

### Medium
1. Make sticks: Get wood x 2 + Use Crafting Table
2. Make rope: Get grass x 2 + Use Crafting Table

### Hard
1. Make weapon: Sticks x 1 + Stone x 2 + Use Crafting Table
2. Make bridge: Rope + Sticks + Use Crafting Table

### Very Hard
1. Get diamond: Bridge + water + collect diamond
2. Make diamond weapon: Diamond + weapon + Use Crafting Table
3. Plant & harvest before time runs out?